@@ -1,14 +1,9 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) Zbigniew Siciarz 2012-2014.
-
-from __future__ import unicode_literals
-
 """
 Gallery syndication feeds.
 """
 
 from django.contrib.syndication.views import Feed
-from django.core.urlresolvers import reverse_lazy
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext as _
 
 from .models import Gallery
@@ -20,7 +15,7 @@ class GalleryFeed(Feed):
     """
 
     title = _("siciarz.net - galleries")
-    link = reverse_lazy('pgallery:gallery_list')
+    link = reverse_lazy("pgallery:gallery_list")
     description = _("Latest photo galleries")
 
     def items(self):
